<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl_PL">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Życie istnieje też poza przeglądarką!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencjonowane dla: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 jest darmowym oprogramowaniem, ale jego stworzenie też wymaga cennego czasu.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę o &lt;a href=&apos;%1&apos;&gt;dotacje&lt;/a&gt; dla dalszego rozwoju %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Przetłumacz %1 na swój język używając %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Dostarczone przez %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Oprogramowanie otwartoźródłowe</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikony zaprojektowane przez %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Wydane na licencji&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Podaj szczegóły twojej licencji</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>Adres &amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kod:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Proszę kup licencję %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Pełna wersja pozwala na oglądanie filmów bez przeszkód.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Kupując pełną wersję, wspieraż także ciężką pracę, jaką włożyłem w stworzenie %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Uruchom w trybie demonstracyjnym</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Wprowadź dane licencji</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kup licencję</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Autor: %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Wszystkie filmy</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Nieobejrzane filmy</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Ostatnio Zaktualizowane</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Ostatnio Dodane</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Ostatnio Zaobserwowane</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Najczęściej Obserwowane</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortuj według</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Oznacz wszystkie jako obserwowane</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Pokaż zaktualizowane</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nie masz żadnej subskrypcji. Użyj symbolu gwiazdki, aby subskrybować kanały.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Wszystkie filmy</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Nieobejrzane filmy</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Oznacz jako obejrzane</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Przestań subskrybować</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Brak zaktualizowanych subskrypcji. </translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Przed chwilą</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>Godzinę temu</numerusform><numerusform>%n godziny temu</numerusform><numerusform>%n godzin temu</numerusform><numerusform>%n godzin temu</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1widziany</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>B</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>B/s</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sek.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>min.</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>pozostało %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 ściągnięte w %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Ściąganie zakończone</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Zmień katalog pobierania...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Wybierz katalog pobierania</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Katalog pobierania został zmieniony.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Aktualnie pobierane pliki zostaną we wcześniejszym katalogu pobierania.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Pobierane do: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Pobrane pliki</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Plik uruchomieniowy został utemperowany prawdopodobnie przez wirusa.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 nie zostanie uruchomione. Spróbuj zainstalować go ponownie.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Zainstaluj ponownie</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Graj</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Graj/Wstrzymaj</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop (przerwij)</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zatrzymaj odtwarzanie po tej ścieżce</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Następna ścieżka</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Poprzednia ścieżka</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Głośniej</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Ciszej</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Przewiń w przód</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Przewiń do tyłu</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Znajdź filmy i kanały po słowie kluczowym</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Przeglądaj filmy po kategorii</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Subskrypcje</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Subskrypcje kanałów</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Rozgość się</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizuj</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zatrzymaj</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Przerwij odtwarzanie i wróć do wyszukiwania</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;oprzedni</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Wróć do poprzedniej ścieżki</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Prze&amp;skocz dalej</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Przejdź do następnego pliku wideo</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Graj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Przywróć odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pełny ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Przełącz na pełny ekran</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Tryb kompaktowy</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ukryj listę odtwarzania i pasek narzędzi</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Otwórz stronę &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Przejdź do strony YouTube i wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Skopiuj &amp;link do strony Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Skopiuj link YouTube odtwarzanego filmu do schowka</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Skopiuj &amp;URL strumienia wideo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopiuj adres URL odtwarzanego wideo do schowka</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Znajdź części filmu</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Znajdź pozostałe części filmu w, miejmy nadzieję, dobrej kolejności</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Usuń wybrane pliki z listy odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Przesuń w &amp;Górę</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Przesuń wyżej zaznaczone pliki</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Przesuń w &amp;Dół</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Przesuń niżej zaznaczone pliki</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Wyczyść ostatnie wyszukiwania</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Czyści historię wyszukiwania. Nieodwracalnie.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Weź to wyłącz</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Narciarz</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Wyświetl stronę</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 on the Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Przekaż &amp;dotację</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Wesprzyj dalszy rozwój %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O &amp;Programie</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informacje o %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Ręczne rozpoczynanie odtwarzania</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Ręcznie odtwarzaj filmy</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Pobrane</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Pokaż szczegóły o pobranych plikach</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Pobierz</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Pobierz aktualny plik</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Wykonaj &amp;migawkę</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Subskrybuj kanał</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Podziel się tym filmem przez %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;E-mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>e-mail</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Ustaw na wierzchu</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Zatrzymaj  po tym filmie</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Zgłoś problem...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Zawęź wyszukiwanie...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Więcej...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Powiązane filmy</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Oglądaj filmy powiązane z aktualnie oglądanym</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Otwórz w &amp;przeglądarce...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Tryb zastrzeżony</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Ukryj filmy mogące zawierać nieodpowiednie treści</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Przełącz pasek &amp;menu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>Uwie&amp;lbiasz %1? Oceń to!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kup%1</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplikacja</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Wideo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Podziel się</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Halp znaczy pomoc</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Naciśnij %1 aby podgłośnić, %2 aby przyciszyć</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Wybierz swoją lokalizację</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Czy na pewno chcesz zamknąć %1 w trakcie pobierania???</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jeśli zamkniesz %1 teraz, To pobieranie będzie anulowane.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Zamnij i anuluj pobieranie</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Poczekaj na zakończenie pobierania</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Wczytywanie...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opuść pełny ekran (&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Pozostały czas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Głośność: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Dźwięk wyciszony</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Dźwięk przywrócony</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksymalna rozdzielczość wideo ustawiona na %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Twoja prywatność jest już bezpieczna</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Pobieranie ukończone</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Dostęp do paska menu można uzyskać naciskając klawisz ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Teraz można wkleić link YouTube do innej aplikacji</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Teraz możesz wkleić URL do innej aplikacji</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link będzie ważny tylko przez ograniczony czas.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Pobieranie %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>z</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>część</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>odcinek</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Przesłane od %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Usuń subskrypcje %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Subskrybuj %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Przełączono na %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Zaprzestano subskrybować %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Zaczęto subskrypcję %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation>kanał</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nowa wersja %1 jest dostępna!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 jest dostępna. Aktualnie posiadasz %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chcesz pobrać teraz?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Pomiń tą wersję</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instaluj aktualizację</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Wybierz film</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 z %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Przygotowywanie</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Niepowodzenie</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Ukończone</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zatrzymano</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Przerwij pobieranie</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Pokaż w %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Otwórz katalog nadrzędny</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Pobierz ponownie</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaż kolejne %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Brak filmów</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nie ma więcej filmów</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortuj według</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Trafność</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Wyświetlenia</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Ocena</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Kiedykolwiek</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dni</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dni</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Czas trwania</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszystkie</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Krótkie</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średnie</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Długie</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Krótsze niż 4 minuty</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Pomiędzy 4 a 20 minut</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Dłuższe niż 20 minut</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Jakość</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>W tym roku</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>aby rozpocząć oglądanie</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>słowo kluczowe</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Zatwierdź</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ostatnie wyszukiwania</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Ostatnie kanały</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Pobierz pełną wersję</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Wstecz</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Na przód</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Idź do %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Powróć do %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Zawęź wyszukiwanie</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Masz na myśli: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Zmień katalog pobierania...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Migawka zapisana do %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Zmieniono katalog zapisywania migawek.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Najpopularniejsze</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>Popularne</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>News</source>
        <translation>Wiadomości</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Gry</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Pobieranie aktualizacji...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Pobieranie %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>Sprawdź dostępność aktualizacji...</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>Dostępna jest wersja %1...</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>Pobranie wersji %1 zakończyło się niepowodzeniem</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>Sprawdź dostępność aktualizacji</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Pobierz aktualizację</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Pobieranie aktualizacji...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>Masz najnowszą wersję.</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>Dostępna jest wersja %1.</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nie można uzyskać dostępu do %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algieria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentyna</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazylia</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Czechy</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francja</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Niemcy</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecja</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Węgry</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indie</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonezja</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlandia</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Włochy</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japonia</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malezja</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksyk</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Holandia</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nowa Zelandia</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipiny</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polska</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rosja</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudyjska</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Południowa Afryka</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Korea Południowa</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Hiszpania</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Szwecja</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tajwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunezja</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turcja</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Zjednoczone Emiraty Arabskie</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Wielka Brytania</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Ogólnoświatowy</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nie można uzyskać dostępu do %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>Masz już najnowszą wersję</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>Pobieranie %1 %2...</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nowa wersja %1 jest dostępna!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 jest dostępna. Aktualnie posiadasz %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chcesz pobrać teraz?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Pobierz aktualizację</translation>
    </message>
</context>
</TS>